"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ECharts = exports.name = void 0;
const koishi_1 = require("koishi");
const echarts_1 = require("echarts");
exports.name = "echarts";
class ECharts extends koishi_1.Service {
    async createChart(width = this.config.width, height = this.config.height, options) {
        let _canvas = this.ctx.canvas.createCanvas(width, height);
        const defaultTextStyle = {
            fontFamily: this.ctx.canvas.getPresetFont(),
            fontSize: 18, // 字体大小
        };
        if (!options.textStyle) {
            options.textStyle = defaultTextStyle;
        }
        (0, echarts_1.setCanvasCreator)(() => _canvas);
        let chart = (0, echarts_1.init)(_canvas);
        chart.setOption(options);
        return _canvas.toBuffer("image/png");
    }
    constructor(ctx, config) {
        super(ctx, "echarts");
        this.config = config;
        ctx
            .command("echarts")
            .option("width", "-w <wid:posint>")
            .option("height", "-t <hei:posint>")
            .action(async ({ options }, set) => {
            const buffer = await this.createChart(options.width, options.height, {
                title: {
                    text: "ECharts 演示",
                },
                tooltip: {},
                legend: {
                    data: ["销量"],
                },
                xAxis: {
                    data: ["衬衫", "羊毛衫", "雪纺衫", "裤子", "高跟鞋", "袜子"],
                },
                yAxis: {},
                series: [
                    {
                        name: "销量",
                        type: "bar",
                        data: [5, 20, 36, 10, 10, 20],
                    },
                ],
            });
            return koishi_1.h.image(buffer, "image/png");
        });
    }
}
exports.ECharts = ECharts;
koishi_1.Context.service("echarts", ECharts);
exports.default = ECharts;
(function (ECharts) {
    ECharts.Config = koishi_1.Schema.object({
        width: koishi_1.Schema.natural().description("Table default width").default(700),
        height: koishi_1.Schema.natural().description("Table default height").default(700),
    }).i18n({
        zh: {
            width: "表格默认宽度",
            height: "表格默认高度",
        },
    });
})(ECharts || (exports.ECharts = ECharts = {}));
